'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = applySourcemap;

var _sourceMap = require('source-map');

/**
 * Applies a sourcemap to Stylelint result.
 *
 * @param {Object} lintResult - Result of StyleLint.
 * @param {Object} sourceMap - Sourcemap object.
 * @return {Object} Rewritten Stylelint result.
 */
function applySourcemap(lintResult, sourceMap) {
  var sourceMapConsumer = new _sourceMap.SourceMapConsumer(sourceMap);

  lintResult.results = lintResult.results.reduce(function (memo, result) {
    if (result.warnings.length) {
      result.warnings.forEach(function (warning) {
        var origPos = sourceMapConsumer.originalPositionFor(warning);
        warning.line = origPos.line;
        warning.column = origPos.column;
        var sameSourceResultIndex = memo.findIndex(function (r) {
          return r.source === origPos.source;
        });
        if (sameSourceResultIndex === -1) {
          memo.push(Object.assign({}, result, {
            source: origPos.source,
            warnings: [warning]
          }));
        } else {
          memo[sameSourceResultIndex].warnings.push(warning);
        }
      });
    } else {
      memo.push(result);
    }
    return memo;
  }, []);

  return lintResult;
} /**
   * Gulp stylelint sourcemap.
   * @module gulp-stylelint/apply-sourcemap
   */