'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = writer;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _stripAnsi = require('strip-ansi');

var _stripAnsi2 = _interopRequireDefault(_stripAnsi);

var _promise = require('promise');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mkdir = (0, _promise.denodeify)(_mkdirp2.default); /**
                                                        * Gulp stylelint writer.
                                                        * @module gulp-stylelint/writer
                                                        */

var writeFile = (0, _promise.denodeify)(_fs2.default.writeFile);

/**
 * Creates the output folder and writes formatted text to a file.
 * @param {String} text - Text to write (may be color-coded).
 * @param {String} dest - Destination path relative to destRoot.
 * @param {String} [destRoot] - Destination root folder, defaults to cwd.
 * @return {Promise} Resolved when folder is created and file is written.
 */
function writer(text, dest) {
  var destRoot = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : process.cwd();

  var fullpath = _path2.default.resolve(destRoot, dest);
  return mkdir(_path2.default.dirname(fullpath)).then(function () {
    return writeFile(fullpath, (0, _stripAnsi2.default)(text));
  });
}